@@ -20,7 +20,6 @@
 #include "tools-dvd.h"
 #include "player-dvd.h"
 #include "control-dvd.h"
-#include "dvddev.h"
 
 #define MENUTIMEOUT     120 // seconds
 #define MAXWAIT4EPGINFO  10 // seconds
@@ -52,7 +51,6 @@ cDvdPlayerControl::cDvdPlayerControl(void) : cControl(player = new cDvdPlayer())
     inputActive = NoneInput;
     inputHide = true;
     forceDvdNavigation = false;
-    cDVD::SpeedControl(2);
     player->setController(this);
     cStatus::MsgReplaying(this, "DVD", NULL, true);
 }
@@ -65,7 +63,6 @@ cDvdPlayerControl::~cDvdPlayerControl()
     assert(dvd_active == true);
     dvd_active = false;
     delete player;
-    cDVD::SpeedControl(0);
 }
 
 bool cDvdPlayerControl::Active(void)
