@@ -277,6 +277,32 @@ const tI18nPhrase DvdPhrases[] = {
         "Dopedn ten",                                   // Czech
 #if VDRVERSNUM >= 10502
         "leri oku"                                         // Trke
+#endif
+    },
+    {
+     "Setup.DVD$DVD-ROM Speed",                             // English
+        "DVD-ROM-Geschwindigkeit",                          // Deutsch
+        "DVD-ROM Speed",                                    // Slovenski
+        "DVD-ROM Speed",                                    // Italiano
+        "DVD-ROM Speed",                                    // Nederlands
+        "DVD-ROM Speed",                                    // Portugus
+        "DVD-ROM Speed",                                    // Franais
+        "DVD-ROM Speed",                                    // Norsk
+        "DVD-ROM Speed",                                    // suomi
+        "DVD-ROM Speed",                                    // Polski
+        "DVD-ROM Speed",                                    // Espaol
+        "DVD-ROM Speed",                                    //  (Greek)
+        "DVD-ROM Speed",                                    // Svenska
+        "DVD-ROM Speed",                                    // Romaneste
+        "DVD-ROM Speed",                                    // Magyar
+        "DVD-ROM Speed",                                    // Catal
+        "DVD-ROM Speed",                                    //  (Russian)
+        "DVD-ROM Speed",                                    // Hrvatski (Croatian)
+        "DVD-ROM Speed",                                    // Eesti
+        "DVD-ROM Speed",                                    // Dansk
+        "DVD-ROM Speed",                                    // Czech
+#if VDRVERSNUM >= 10502
+        "DVD-ROM Speed"                                     // Trke
 #endif
     },
     {
