@@ -8,7 +8,7 @@ const tI18nPhrase Phrases[] = {
   { "Extended recordings menu",
     "Erweitertes Aufzeichnungs-Men",
     "",
-    "",
+    "Menu registrazioni esteso",
     "",
     "",
     "Menu enregistrement tandu",
@@ -30,7 +30,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Open",
     "ffnen",
     "",
-    "",
+    "Apri",
     "",
     "",
     "Ouvrir",
@@ -52,7 +52,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Back",
     "Zurck",
     "",
-    "",
+    "Indietro",
     "",
     "",
     "Retour",
@@ -74,7 +74,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Cancel",
     "Abbrechen",
     "",
-    "",
+    "Annulla",
     "",
     "",
     "Interrompre",
@@ -96,7 +96,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Play",
     "Wiedergabe",
     "",
-    "",
+    "Esegui",
     "",
     "",
     "Montrer",
@@ -118,7 +118,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Commands",
     "Befehle",
     "",
-    "",
+    "Comandi",
     "",
     "",
     "Commande",
@@ -140,7 +140,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Rewind",
     "Anfang",
     "",
-    "",
+    "Riavvolgi",
     "",
     "",
     "Dbut",
@@ -162,7 +162,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Create",
     "Anlegen",
     "",
-    "",
+    "Crea",
     "",
     "",
     "Crer",
@@ -184,7 +184,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Edit",
     "Editieren",
     "",
-    "",
+    "Modifica",
     "",
     "",
     "diter",
@@ -206,7 +206,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Rename",
     "Umbenennen",
     "",
-    "",
+    "Rinomina",
     "",
     "",
     "Renommer",
@@ -228,7 +228,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Move",
     "Verschieben",
     "",
-    "",
+    "Sposta",
     "",
     "",
     "Dplacer",
@@ -250,7 +250,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Delete",
     "Lschen",
     "",
-    "",
+    "Cancella",
     "",
     "",
     "Effacer",
@@ -272,7 +272,7 @@ const tI18nPhrase Phrases[] = {
   { "Button$Info",
     "Info",
     "",
-    "",
+    "Info",
     "",
     "",
     "Info",
@@ -294,7 +294,7 @@ const tI18nPhrase Phrases[] = {
   { "New folder",
     "Neues Verzeichnis",
     "",
-    "",
+    "Nuova cartella",
     "",
     "",
     "Nouveau dossier",
@@ -316,7 +316,7 @@ const tI18nPhrase Phrases[] = {
   { "Rename",
     "Umbenennen",
     "",
-    "",
+    "Rinomina",
     "",
     "",
     "Renommer",
@@ -338,7 +338,7 @@ const tI18nPhrase Phrases[] = {
   { "Show recording date",
     "Aufnahmedatum anzeigen",
     "",
-    "",
+    "Mostra data registrazione",
     "",
     "",
     "Afiicher la date d'enregistrement",
@@ -360,7 +360,7 @@ const tI18nPhrase Phrases[] = {
   { "Show recording time",
     "Aufnahmezeit anzeigen",
     "",
-    "",
+    "Mostra ora registrazione",
     "",
     "",
     "Afficher l'heure d'enregistrement",
@@ -382,7 +382,7 @@ const tI18nPhrase Phrases[] = {
   { "Show recording length",
     "Aufnahmelnge anzeigen",
     "",
-    "",
+    "Mostra durata registrazione",
     "",
     "",
     "Afficher la longeur de l'enregistrement",
@@ -404,7 +404,7 @@ const tI18nPhrase Phrases[] = {
   { "Hide main menu entry",
     "Hauptmeneintrag ausblenden",
     "",
-    "",
+    "Nascondi voce nel menu principale",
     "",
     "",
     "Menu Enregistrement tandu invisible",
@@ -426,7 +426,7 @@ const tI18nPhrase Phrases[] = {
   { "Replace original recordings menu",
     "Originales Aufzeichnungsmen ersetzen",
     "",
-    "",
+    "Sostituisci menu registrazioni originale",
     "",
     "",
     "Remplacer le nenu original Enregistrement",
@@ -448,7 +448,7 @@ const tI18nPhrase Phrases[] = {
   { "Show alternative to new marker",
     "Alternative zu Neu-Marker anzeigen",
     "",
-    "",
+    "Mostra alternative al nuovo marcatore",
     "",
     "",
     "Afficher les nouveaux symbols alternatifs",
@@ -470,7 +470,7 @@ const tI18nPhrase Phrases[] = {
   { "Please insert DVD %s",
     "Bitte DVD %s einlegen",
     "",
-    "",
+    "Per favore inserisci DVD %s",
     "",
     "",
     "Mettez le DVD %s dans le lecteur",
@@ -492,7 +492,7 @@ const tI18nPhrase Phrases[] = {
   { "Error while mounting DVD!",
     "Fehler beim Einhngen der DVD!",
     "",
-    "",
+    "Errore durante montaggio DVD!",
     "",
     "",
     "Erreur lors du montage du DVD!",
@@ -514,7 +514,7 @@ const tI18nPhrase Phrases[] = {
   { "Recording not found on DVD!",
     "Aufzeichnung auf DVD nicht gefunden!",
     "",
-    "",
+    "Registrazione non trovata nel DVD!",
     "",
     "",
     "Il n'y a pas d'enregistrement sur le DVD!",
@@ -536,7 +536,7 @@ const tI18nPhrase Phrases[] = {
   { "Script 'dvdarchive.sh' not found!",
     "Skript 'dvdarchive.sh' wurde nicht gefunden!",
     "",
-    "",
+    "Script 'dvdarchive.sh non trovato!",
     "",
     "",
     "Impossible de trouver le script 'dvdarchive.sh'!",
@@ -558,7 +558,7 @@ const tI18nPhrase Phrases[] = {
   { "[base dir]",
     "[Stammverzeichnis]",
     "",
-    "",
+    "[dir. base]",
     "",
     "",
     "[Dossier racine]",
@@ -580,7 +580,7 @@ const tI18nPhrase Phrases[] = {
   { "No DVD in drive!",
     "Keine DVD im Laufwerk!",
     "",
-    "",
+    "Nessun DVD nel lettore!",
     "",
     "",
     "Pas de DVD dans le lecteur!",
@@ -602,7 +602,7 @@ const tI18nPhrase Phrases[] = {
   { "Error while linking [0-9]*.vdr!",
     "Fehler beim Anlegen der Symlinks [0-9]*.vdr!",
     "",
-    "",
+    "Errore creazione collegamento [0-9]*.vdr!",
     "",
     "",
     "Erreur lors de la cration des racourcis [0-9]*.vdr!",
@@ -624,7 +624,7 @@ const tI18nPhrase Phrases[] = {
   { "sudo or mount --bind / umount error (vfat system)",
     "sudo oder mount --bind / umount Fehler (VFAT-System)",
     "",
-    "",
+    "Errore sudo o mount --bind / umount (sistema vfat)",
     "",
     "",
     "Erreur sudo ou mount --bind / umount (Systeme VFAT)",
@@ -646,7 +646,7 @@ const tI18nPhrase Phrases[] = {
   { "Details",
     "Details",
     "",
-    "",
+    "Dettagli",
     "",
     "",
     "Dtails",
@@ -668,7 +668,7 @@ const tI18nPhrase Phrases[] = {
   { "DVD plugin is not installed!",
     "Das DVD-Plugin ist nicht installiert!",
     "",
-    "",
+    "Plugin DVD non installato!",
     "",
     "",
     "Le plugin DVD n'est pas install!",
@@ -690,7 +690,7 @@ const tI18nPhrase Phrases[] = {
   { "Invalid filename!",
     "Ungltiger Dateiname!",
     "",
-    "",
+    "Nome file non valido!",
     "",
     "",
     "Nom de fichiers n'est pas valide'",
@@ -712,7 +712,7 @@ const tI18nPhrase Phrases[] = {
   { "Moving into own sub-directory not allowed!",
     "Verschieben in eigenes Unterverzeichnis nicht erlaubt!",
     "",
-    "",
+    "Spostamento all'interno di sotto directory non permesso!",
     "",
     "",
     "Dplacer dans le sous-dossier propre, n'est pas possible!",
@@ -734,7 +734,7 @@ const tI18nPhrase Phrases[] = {
   { "Sort by name",
     "Sortieren nach Namen",
     "",
-    "",
+    "Ordina per nome",
     "",
     "",
     "Triage selon le nom",
@@ -756,7 +756,7 @@ const tI18nPhrase Phrases[] = {
   { "Sort by date",
     "Sortieren nach Datum",
     "",
-    "",
+    "Ordina per data",
     "",
     "",
     "Triage selon date",
@@ -778,7 +778,7 @@ const tI18nPhrase Phrases[] = {
   { "Show nr. of new recordings of a directory",
     "Anzahl der neuen Aufz. eines Ordners anzeigen",
     "",
-    "",
+    "Mostra numero di nuove registrazioni di una directory",
     "",
     "",
     "Afficher le nombre de nouveaux enregistrements dans les dossiers",
@@ -800,7 +800,7 @@ const tI18nPhrase Phrases[] = {
   { "Sorting",
     "Sortierung",
     "",
-    "",
+    "Ordinamento",
     "",
     "",
     "Triage",
@@ -822,7 +822,7 @@ const tI18nPhrase Phrases[] = {
   { "ascending",
     "aufsteigend",
     "",
-    "",
+    "ascendente",
     "",
     "",
     "montant",
@@ -844,7 +844,7 @@ const tI18nPhrase Phrases[] = {
   { "descending",
     "absteigend",
     "",
-    "",
+    "decrescente",
     "",
     "",
     "descendant",
@@ -866,7 +866,7 @@ const tI18nPhrase Phrases[] = {
   { "Jump to last replayed recording",
     "Springe zur zuletzt abgespielten Aufzeichnung",
     "",
-    "",
+    "Vai all'ultima registrazione riprodotta",
     "",
     "",
     "Retour au dernier enregistrement lu",
@@ -888,7 +888,7 @@ const tI18nPhrase Phrases[] = {
   { "Call plugin after playback",
     "Nach Wiedergabe Plugin aufrufen",
     "",
-    "",
+    "Chiama plugin dopo esecuzione",
     "",
     "",
     "Aprs la lecture dmarer le plugin",
@@ -910,7 +910,7 @@ const tI18nPhrase Phrases[] = {
   { "Move recordings in progress",
     "Es werden Aufzeichungen verschoben",
     "",
-    "",
+    "Spostamento registrazioni in corso",
     "",
     "",
     "Enregistrements en cours de dplacement",
@@ -932,7 +932,7 @@ const tI18nPhrase Phrases[] = {
   { "Limit bandwidth for move recordings",
     "Bandbreite beim Verschieben begrenzen",
     "",
-    "",
+    "Limiti banda per spostamento registrazioni",
     "",
     "",
     "Limiter la bande passante lors du dplacement",
@@ -951,10 +951,10 @@ const tI18nPhrase Phrases[] = {
     "",
     "Omezit rychlost pro pesun nahrvek",
   },
-  { "Target filesystem filled- try anyway?",
+  { "Target filesystem filled - try anyway?",
     "Zielpartition voll - trotzdem versuchen?",
     "",
-    "",
+    "Partizione di destinazione piena - provare comunque?",
     "",
     "",
     "La partition de dstination est pleine - essayer tout de mme?",
@@ -976,7 +976,7 @@ const tI18nPhrase Phrases[] = {
   { "Path",
     "Pfad",
     "",
-    "",
+    "Percorso",
     "",
     "",
     "Chemin",
@@ -998,7 +998,7 @@ const tI18nPhrase Phrases[] = {
   { "Size",
     "Gre",
     "",
-    "",
+    "Dimensione",
     "",
     "",
     "Taille",
@@ -1020,7 +1020,7 @@ const tI18nPhrase Phrases[] = {
   { "Use VDR's recording info menu",
     "VDRs Aufzeichnungs-Info-Men benutzen",
     "",
-    "",
+    "Utilizza menu info registrazioni di VDR",
     "",
     "",
     "Utiliser le menu info enregistrement de VDR",
@@ -1042,7 +1042,7 @@ const tI18nPhrase Phrases[] = {
   { "Added recording to cutter queue",
     "Aufzeichnung der Schnitt-Warteschlange hinzugefgt",
     "",
-    "",
+    "Aggiunta registrazione alla coda tagli",
     "",
     "",
     "Enregistrement ajout  la file d'attente de dcoupe",
@@ -1064,7 +1064,7 @@ const tI18nPhrase Phrases[] = {
   { "Recording already in cutter queue!",
     "Aufzeichnung bereits in Schnitt-Warteschlange",
     "",
-    "",
+    "Registrazione gi presente nella coda tagli!",
     "",
     "",
     "L'enregistrement est dj dans la queue d'attente dcoupe!",
@@ -1086,7 +1086,7 @@ const tI18nPhrase Phrases[] = {
   { "Cutter queue not empty",
     "Schnitt-Warteschlange nicht leer",
     "",
-    "",
+    "Coda tagli non vuota",
     "",
     "",
     "Queue d'attente dcoupe n'est pas vide",
@@ -1108,7 +1108,7 @@ const tI18nPhrase Phrases[] = {
   { "Move recordings in progress",
     "Es werden Aufzeichnungen verschoben",
     "",
-    "",
+    "Spostamento registrazioni in corso",
     "",
     "",
     "Des enregistrements sont en dplacement",
@@ -1130,7 +1130,7 @@ const tI18nPhrase Phrases[] = {
   { "Cancel moving?",
     "Verschieben abbrechen?",
     "",
-    "",
+    "Anullare spostamento?",
     "",
     "",
     "Interrompre le dplacement?",
@@ -1152,7 +1152,7 @@ const tI18nPhrase Phrases[] = {
   { "Patch font",
     "Font patchen",
     "",
-    "",
+    "Patch caratteri",
     "",
     "",
     "Patch des police",
@@ -1174,7 +1174,7 @@ const tI18nPhrase Phrases[] = {
   { "Show free disk space for each file system",
     "Freien Speicherplatz fr jede Partition anzeigen",
     "",
-    "",
+    "Mostra spazio libero per ogni partizione",
     "",
     "",
     "Afficher la place libre de chaque partition",
@@ -1196,7 +1196,7 @@ const tI18nPhrase Phrases[] = {
   { "Can't get filesystem information",
     "Kann Dateisysteminformationen nicht ermitteln",
     "",
-    "",
+    "Impossibile ottenere informazioni sulla partizione",
     "",
     "",
     "Impossible de dterminer les informations du systme de fichiers",
@@ -1218,7 +1218,7 @@ const tI18nPhrase Phrases[] = {
   { "Rename/Move failed!",
     "Umbenennen/Verschieben fehlgeschlagen!",
     "",
-    "",
+    "Rinominazione/Spostamento fallito!",
     "",
     "",
     "Renommer/dplacer  chou!",
@@ -1240,7 +1240,7 @@ const tI18nPhrase Phrases[] = {
   { "Use cutter queue",
     "Schnittwarteschlange benutzen",
     "",
-    "",
+    "Utilizza coda tagli",
     "",
     "",
     "",
