@@ -255,7 +255,7 @@ void cMenuChannelscan::Set()
    /* TODO  aktivate loop mode again!
    if (loopMode && ::Setup.DiSEqC)
    {
-      Add(new cMenuInfoItem("Scanning configured satellites"));
+      Add(new cMenuInfoItem(tr("Scanning configured satellites")));
       AddBlankLineItem(4);
    }
 
@@ -297,7 +297,7 @@ void cMenuChannelscan::Set()
                   Add(new cMenuEditIntItem(tr("Frequency (MHz)"), &frequency));  
                   Add(new cMenuEditChrItem(tr("Polarization"),&polarization, "HVLR"));
                   Add(new cMenuEditIntItem(tr("Symbolrate"), &symbolrate));
-                  Add(new cMenuEditStraItem("FEC", &fecStat, 10, fecTexts ));
+                  Add(new cMenuEditStraItem(tr("FEC"), &fecStat, 10, fecTexts ));
                   break;          
           
           case TERR:
