@@ -27,23 +27,13 @@ protected:
 	virtual void Receive(uchar *Data, int Length);
 
 public:
-#if VDRVERSNUM < 10500
-	cStreamdevLiveReceiver(cStreamdevStreamer *Streamer, int Ca, int Priority, const int *Pids);
-#else
 	cStreamdevLiveReceiver(cStreamdevStreamer *Streamer, tChannelID ChannelID, int Priority, const int *Pids);
-#endif
 	virtual ~cStreamdevLiveReceiver();
 };
 
-#if VDRVERSNUM < 10500
-cStreamdevLiveReceiver::cStreamdevLiveReceiver(cStreamdevStreamer *Streamer, int Ca, 
-                                               int Priority, const int *Pids):
-		cReceiver(Ca, Priority, 0, Pids),
-#else
 cStreamdevLiveReceiver::cStreamdevLiveReceiver(cStreamdevStreamer *Streamer, tChannelID ChannelID, 
                                                int Priority, const int *Pids):
 		cReceiver(ChannelID, Priority, 0, Pids),
-#endif
 		m_Streamer(Streamer)
 {
 }
@@ -323,9 +313,10 @@ void cStreamdevPatFilter::Process(u_short Pid, u_char Tid, const u_char *Data, i
 
 // --- cStreamdevLiveStreamer -------------------------------------------------
 
-cStreamdevLiveStreamer::cStreamdevLiveStreamer(int Priority):
+cStreamdevLiveStreamer::cStreamdevLiveStreamer(int Priority, std::string Parameter):
 		cStreamdevStreamer("streamdev-livestreaming"),
 		m_Priority(Priority),
+		m_Parameter(Parameter),
 		m_NumPids(0),
 		m_StreamType(stTSPIDS),
 		m_Channel(NULL),
@@ -433,11 +424,7 @@ void cStreamdevLiveStreamer::StartReceiver(void)
 	DELETENULL(m_Receiver);
 	if (m_NumPids > 0) {
 		Dprintf("Creating Receiver to respect changed pids\n");
-#if VDRVERSNUM < 10500
-		m_Receiver = new cStreamdevLiveReceiver(this, m_Channel->Ca(), m_Priority, m_Pids);
-#else
 		m_Receiver = new cStreamdevLiveReceiver(this, m_Channel->GetChannelID(), m_Priority, m_Pids);
-#endif
 		if (IsRunning() && m_Device != NULL) {
 			Dprintf("Attaching new receiver\n");
 			Attach();
@@ -488,7 +475,7 @@ bool cStreamdevLiveStreamer::SetChannel(const cChannel *Channel, eStreamType Str
 
 	case stExtern:
 		m_ExtRemux = new cExternRemux(m_Channel->Vpid(), m_Channel->Apids(), m_Channel->Dpids(),
-		                              m_Channel->Spids());
+		                              m_Channel->Spids(), m_Parameter);
 		return SetPids(m_Channel->Vpid(), Apids, Dpids, m_Channel->Spids());
 
 	case stTSPIDS:
@@ -617,7 +604,6 @@ std::string cStreamdevLiveStreamer::Report(void)
 
 // --- cStreamdevFilterStreamer -------------------------------------------------
 
-#if VDRVERSNUM >= 10300
 cStreamdevFilterStreamer::cStreamdevFilterStreamer():
 		cStreamdevStreamer("streamdev-filterstreaming"),
 		m_Device(NULL),
@@ -719,5 +705,3 @@ void cStreamdevFilterStreamer::ChannelSwitch(const cDevice *Device, int ChannelN
 	}
 }
 #endif
-
-#endif // if VDRVERSNUM >= 10300
