@@ -244,7 +244,6 @@ static int CollectSections(int card_no, int pid, int table_id, char **sects, int
 // previous channel somewhere in the pipe. Whe need to remove that.
 static void DiscardBufferedSections(int card_no, uint16_t pid, int table_id)
 {
-  int tmp;
   int fd;
   char name[100];
   int ret = -1;
@@ -273,7 +272,7 @@ static void DiscardBufferedSections(int card_no, uint16_t pid, int table_id)
 
     ret = poll(&pi, 1, 0);
     if(ret > 0 && (pi.revents & POLLIN)) {
-      tmp = read(fd, buf, SECTSIZE);
+      read(fd, buf, SECTSIZE);
       n++;
     }
   } while (ret > 0);
