@@ -478,7 +478,7 @@ const tI18nPhrase Phrases[] = {
     "", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Taille Police (pixel)", // French
     "", // Norwegian
     "Kirjasintyypin koko (px)", // Finnish
     "", // Polish
@@ -751,7 +751,7 @@ const tI18nPhrase Phrases[] = {
     "Colore personalizzato", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Couleur personnalise", // French
     "", // Norwegian
     "Muokattava vri", // Finnish
     "", // Polish
@@ -772,7 +772,7 @@ const tI18nPhrase Phrases[] = {
     "Personalizzato", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Personnalis", // French
     "", // Norwegian
     "muokattava", // Finnish
     "", // Polish
@@ -793,7 +793,7 @@ const tI18nPhrase Phrases[] = {
     "Valore rosso", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Valeur Rouge", // French
     "", // Norwegian
     "Punainen", // Finnish
     "", // Polish
@@ -814,7 +814,7 @@ const tI18nPhrase Phrases[] = {
     "Valore verde", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Valeur Vert", // French
     "", // Norwegian
     "Vihre", // Finnish
     "", // Polish
@@ -835,7 +835,7 @@ const tI18nPhrase Phrases[] = {
     "Valore azzurro", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Valeur Bleu", // French
     "", // Norwegian
     "Sininen", // Finnish
     "", // Polish
@@ -856,7 +856,7 @@ const tI18nPhrase Phrases[] = {
     "Valore trasparenza", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Valeur de transparence", // French
     "", // Norwegian
     "Lpinkyvyys", // Finnish
     "", // Polish
@@ -877,7 +877,7 @@ const tI18nPhrase Phrases[] = {
     "Selezione sorgente DVB", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Slection Source DVB", // French
     "", // Norwegian
     "Tekstityslhteen valinta", // Finnish
     "", // Polish
@@ -898,7 +898,7 @@ const tI18nPhrase Phrases[] = {
     "Tutte", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Tous", // French
     "", // Norwegian
     "kaikki", // Finnish
     "", // Polish
@@ -919,7 +919,7 @@ const tI18nPhrase Phrases[] = {
     "Solo DVB-S", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Seulement DVB-S", // French
     "", // Norwegian
     "vain DVB-S", // Finnish
     "", // Polish
@@ -940,7 +940,7 @@ const tI18nPhrase Phrases[] = {
     "Solo DVB-T", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Seulement DVB-T", // French
     "", // Norwegian
     "vain DVB-T", // Finnish
     "", // Polish
@@ -961,7 +961,7 @@ const tI18nPhrase Phrases[] = {
     "Solo DVB-C", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Seulement DVB-C", // French
     "", // Norwegian
     "vain DVB-C", // Finnish
     "", // Polish
@@ -982,7 +982,7 @@ const tI18nPhrase Phrases[] = {
     "Modo pagina", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Mode page", // French
     "", // Norwegian
     "sivun valinta", // Finnish
     "", // Polish
@@ -1003,7 +1003,7 @@ const tI18nPhrase Phrases[] = {
     "Selezione pagina", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Page de slection", // French
     "", // Norwegian
     "Tekstityssivun valinta", // Finnish
     "", // Polish
@@ -1024,7 +1024,7 @@ const tI18nPhrase Phrases[] = {
     "Modo sottotitoli", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Mode de sous-titres TXT", // French
     "", // Norwegian
     "Tekstitystapa", // Finnish
     "", // Polish
@@ -1045,7 +1045,7 @@ const tI18nPhrase Phrases[] = {
     "Pagina manuale sottotitoli", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Page des sous-titres", // French
     "", // Norwegian
     "Asetettu tekstityssivu", // Finnish
     "", // Polish
@@ -1066,7 +1066,7 @@ const tI18nPhrase Phrases[] = {
     "Settaggi pagina sottotitoli", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Conf. Page sous-titres TXT", // French
     "", // Norwegian
     "Tekstityssivun asetukset", // Finnish
     "", // Polish
@@ -1087,7 +1087,7 @@ const tI18nPhrase Phrases[] = {
     "Automatico", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Auto", // French
     "", // Norwegian
     "automaattinen", // Finnish
     "", // Polish
@@ -1108,7 +1108,7 @@ const tI18nPhrase Phrases[] = {
     "Manuale", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Manuel", // French
     "", // Norwegian
     "manuaalinen", // Finnish
     "", // Polish
@@ -1129,7 +1129,7 @@ const tI18nPhrase Phrases[] = {
     "Disattivati", // Italian
     "", // Dutch
     "", // Portuguese
-    "", // French
+    "Dsactiv", // French
     "", // Norwegian
     "pois", // Finnish
     "", // Polish
