@@ -11,7 +11,9 @@
 
 #include <vdr/plugin.h>
 #include <stdarg.h>
+#if APIVERSNUM < 10507
 #include "i18n.h"
+#endif
 
 #define YAEPG_ERROR(...)		cYaepg::LogMsg(YLOG_ERR, __VA_ARGS__)
 #define YAEPG_INFO(...)			cYaepg::LogMsg(YLOG_INF, __VA_ARGS__)
@@ -22,7 +24,7 @@ typedef enum {
 } eYlog_t;
 
 static const char *VERSION        = "0.0.2.2";
-static const char *DESCRIPTION    = "Yet Another EPG";
-static const char *MAINMENUENTRY  = "Yaepg";
+static const char *DESCRIPTION    = trNOOP("Yet Another EPG");
+static const char *MAINMENUENTRY  = tr("Yaepg");
 
 #endif /* _YAEPG__H */
