@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: device.c 1.157 2008/03/09 10:03:34 kls Exp $
+ * $Id: device.c 1.157.1.1 2008/04/13 11:16:00 kls Exp $
  */
 
 #include "device.h"
@@ -534,26 +534,26 @@ cDevice *cDevice::GetDevice(const cChannel *Channel, int Priority, bool LiveView
              imp <<= 1; imp |= device[i]->HasDecoder();                                                              // avoid full featured cards
              imp <<= 1; imp |= NumUsableSlots ? !ChannelCamRelations.CamDecrypt(Channel->GetChannelID(), j + 1) : 0; // prefer CAMs that are known to decrypt this channel
 //ML
-       badPriority = device[i]->GetMaxBadPriority(Channel);
-       if (badPriority >= Priority || (badPriority == -1 && Priority < Setup.PrimaryLimit)) {
-            // channel is not available for the requested prioity
-            imp = 0xFFFFFFFF;
-         } else {
-            switch (badPriority) {
-               case -2: // not affected by LNB-sharing
-                  imp2 = 0;
-                  break;
-               case -1: // the primary device would need a channel switch
-                  imp += 1 <<  17;
-                  imp2 = 0xFFFFFFFF | 1 << 17;
-                  break;
-               default: // a device receiving with lower priority would need to be stopped
-                  imp += badPriority << 8;
-                  imp2 = 0xFFFFFFFF | badPriority << 8;
-                  break;
-               }
-            }
-         if (imp < Impact && imp2 < Impact) {
+             badPriority = device[i]->GetMaxBadPriority(Channel);
+             if (badPriority >= Priority || (badPriority == -1 && Priority < Setup.PrimaryLimit)) {
+                // channel is not available for the requested prioity
+                imp = 0xFFFFFFFF;
+             } else {
+                switch (badPriority) {
+                   case -2: // not affected by LNB-sharing
+                      imp2 = 0;
+                      break;
+                   case -1: // the primary device would need a channel switch
+                      imp += 1 <<  17;
+                      imp2 = 0xFFFFFFFF | 1 << 17;
+                      break;
+                   default: // a device receiving with lower priority would need to be stopped
+                      imp += badPriority << 8;
+                      imp2 = 0xFFFFFFFF | badPriority << 8;
+                      break;
+                }
+             }
+             if (imp < Impact && imp2 < Impact) {
 //ML-End
                 // This device has less impact than any previous one, so we take it.
                 Impact = imp;
@@ -1469,7 +1469,7 @@ int cDevice::PlayPesPacket(const uchar *Data, int Length, bool VideoOnly)
                uchar SubStreamIndex = SubStreamId & 0x1F;
 
                // Compatibility mode for old VDR recordings, where 0xBD was only AC3:
-pre_1_3_19_PrivateStreamDeteced:
+pre_1_3_19_PrivateStreamDetected:
                if (pre_1_3_19_PrivateStream > MIN_PRE_1_3_19_PRIVATESTREAM) {
                   SubStreamId = c;
                   SubStreamType = 0x80;
@@ -1510,7 +1510,8 @@ pre_1_3_19_PrivateStreamDeteced:
                          if (pre_1_3_19_PrivateStream > MIN_PRE_1_3_19_PRIVATESTREAM) {
                             dsyslog("switching to pre 1.3.19 Dolby Digital compatibility mode - substream id = %02X", SubStreamId);
                             ClrAvailableTracks();
-                            goto pre_1_3_19_PrivateStreamDeteced;
+                            pre_1_3_19_PrivateStream = MIN_PRE_1_3_19_PRIVATESTREAM + 1;
+                            goto pre_1_3_19_PrivateStreamDetected;
                             }
                          }
                  }
