@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: device.h 1.86 2007/10/21 09:21:52 kls Exp $
+ * $Id: device.h 1.91 2008/02/23 13:13:04 kls Exp $
  */
 
 #ifndef __DEVICE_H
@@ -101,6 +101,7 @@ private:
   static int useDevice;
   static cDevice *device[MAXDEVICES];
   static cDevice *primaryDevice;
+  static cDevice *avoidDevice;
 public:
   static int NumDevices(void) { return numDevices; }
          ///< Returns the total number of devices.
@@ -170,6 +171,9 @@ public:
          ///< Returns -2 if there are no such devices and the primary device 
          ///< would not be affected by switching to the requested channel.
 //ML-End
+  static void SetAvoidDevice(cDevice *Device) { avoidDevice = Device; }
+         ///< Sets the given Device to be temporarily avoided in the next call to
+         ///< GetDevice(const cChannel, int, bool).
   static void Shutdown(void);
          ///< Closes down all devices.
          ///< Must be called at the end of the program.
@@ -332,7 +336,12 @@ private:
 protected:
   void StartSectionHandler(void);
        ///< A derived device that provides section data must call
-       ///< this function to actually set up the section handler.
+       ///< this function (typically in its constructor) to actually set
+       ///< up the section handler.
+  void StopSectionHandler(void);
+       ///< A device that has called StartSectionHandler() must call this
+       ///< function (typically in its destructor) to stop the section
+       ///< handler.
 public:
   virtual int OpenFilter(u_short Pid, u_char Tid, u_char Mask);
        ///< Opens a file handle for the given filter data.
@@ -411,6 +420,8 @@ private:
 protected:
   virtual void SetAudioTrackDevice(eTrackType Type);
        ///< Sets the current audio track to the given value.
+  virtual void SetSubtitleTrackDevice(eTrackType Type);
+       ///< Sets the current subtitle track to the given value.
 public:
   void ClrAvailableTracks(bool DescriptionsOnly = false, bool IdsOnly = false);
        ///< Clears the list of currently availabe tracks. If DescriptionsOnly
