@@ -80,10 +80,10 @@ void cDvbOsd::SetActive(bool On)
             Cmd(OSD_SetWindow, 0, i + 1);
             Cmd(OSD_Close);
             }
-	     if (vidWin.bpp != 0) {
-	         Cmd(OSD_SetWindow, 0, 5);
-	         Cmd(OSD_Close);
-	         }
+        if (vidWin.bpp != 0) {
+           Cmd(OSD_SetWindow, 0, MAXNUMWINDOWS);
+           Cmd(OSD_Close);
+           }
         shown = false;
         }
      }
@@ -119,6 +119,10 @@ eOsdError cDvbOsd::SetAreas(const tArea *Areas, int NumAreas)
          Cmd(OSD_SetWindow, 0, i + 1);
          Cmd(OSD_Close);
          }
+     if (vidWin.bpp != 0) {
+        Cmd(OSD_SetWindow, 0, MAXNUMWINDOWS);
+        Cmd(OSD_Close);
+        }
      shown = false;
      }
   return cOsd::SetAreas(Areas, NumAreas);
@@ -203,10 +207,10 @@ void cDvbOsd::Flush(void)
          Cmd(OSD_MoveWindow, 0, Left() + Bitmap->X0(), Top() + Bitmap->Y0());
          }
      if (vidWin.bpp != 0) {
-       Cmd(OSD_SetWindow, 0, 5);
-       Cmd(OSD_Command(OSD_MoveWindow+1), vidWin.bpp, vidWin.x1, vidWin.y1,
-       vidWin.x2, vidWin.y2, (void *)0);
-     }
+        Cmd(OSD_SetWindow, 0, MAXNUMWINDOWS);
+        Cmd(OSD_OpenRaw, vidWin.bpp, vidWin.x1, vidWin.y1,
+            vidWin.x2, vidWin.y2, (void *)0);
+        }
      shown = true;
      }
 }
