@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: menuitems.c 1.55 2007/11/03 15:01:01 kls Exp $
+ * $Id: menuitems.c 1.58 2008/02/10 16:03:30 kls Exp $
  */
 
 #include "menuitems.h"
@@ -34,9 +34,8 @@ cMenuEditItem::~cMenuEditItem()
 
 void cMenuEditItem::SetValue(const char *Value)
 {
-  char *buffer = NULL;
-  asprintf(&buffer, "%s:\t%s", name, Value);
-  SetText(buffer, false);
+  cString buffer = cString::sprintf("%s:\t%s", name, Value);
+  SetText(buffer);
   cStatus::MsgOsdCurrentItem(buffer);
 }
 
@@ -620,6 +619,168 @@ eOSState cMenuEditStrItem::ProcessKey(eKeys Key)
   return osContinue;
 }
 
+// --- cMenuEditRecPathItem --------------------------------------------------
+
+cMenuEditRecPathItem::cMenuEditRecPathItem(const char* Name, char* Path,
+   int Length): cMenuEditStrItem(Name, Path, Length, tr(FileNameChars))
+{
+  SetBase(Path);
+}
+
+cMenuEditRecPathItem::~cMenuEditRecPathItem()
+{
+}
+
+void cMenuEditRecPathItem::SetBase(const char* Path)
+{
+  if (!Path)
+      base[0] = 0;
+  Utf8Strn0Cpy(base, Path, sizeof(base));
+  char* p = strrchr(base, '~');
+  if (p)
+     p[0] = 0;
+  else
+     base[0] = 0;
+}
+
+void cMenuEditRecPathItem::FindNextLevel()
+{
+  char item[MaxFileName];
+
+  for (cRecording *recording = Recordings.First(); recording; recording = Recordings.Next(recording))
+  {
+     char* p;
+     Utf8Strn0Cpy(item, recording->Name(), sizeof(item));
+     stripspace(value);
+     lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+     if (!lengthUtf8)
+        p = strchr(item, '~');
+     else {
+        if (strstr(item, value) != item)
+           continue;
+        if (item[lengthUtf8] != '~')
+           continue;
+        p = strchr(item + lengthUtf8 + 1, '~');
+        }
+     if (!p)
+        continue;
+     p[0] = 0;
+     Utf8Strn0Cpy(base, value, length);
+     Utf8Strn0Cpy(value, item, length);
+     lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+     return;
+     }
+}
+
+void cMenuEditRecPathItem::Find(bool Next)
+{
+  char item[MaxFileName];
+  char lastItem[MaxFileName] = "";
+
+  for (cRecording *recording = Recordings.First(); recording; recording = Recordings.Next(recording))
+  {
+     const char* recName = recording->Name();
+     if (Utf8StrLen(base) && strstr(recName, base) != recName)
+        continue;
+     if (Utf8StrLen(base) && recName[Utf8StrLen(base)] != '~')
+        continue;
+     Utf8Strn0Cpy(item, recName, sizeof(item));
+     char* p = strchr(item + Utf8StrLen(base) + 1, '~');
+     if (!p)
+        continue;
+     p[0] = 0;
+     if (!Next && (strcmp(item, value) == 0)) {
+        if (strlen(lastItem))
+           Utf8Strn0Cpy(value, lastItem, length);
+        lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+        return;
+        }
+     if (strcmp(lastItem, item) != 0) {
+        if(Next && Utf8StrLen(lastItem) && strcmp(lastItem, value) == 0) {
+           Utf8Strn0Cpy(value, item, length);
+           lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+           return;
+           }
+        Utf8Strn0Cpy(lastItem, item, sizeof(lastItem));
+        }
+     }
+}
+
+void cMenuEditRecPathItem::SetHelpKeys(void)
+{
+  cSkinDisplay::Current()->SetButtons(tr("Rename$Up"), tr("Rename$Down"), tr("Rename$Previous"), tr("Rename$Next"));
+}
+
+eOSState cMenuEditRecPathItem::ProcessKey(eKeys Key)
+{
+  switch (Key) {
+    case kLeft:
+    case kRed:    // one level up
+                  if (!InEditMode())
+                     return cMenuEditItem::ProcessKey(Key);
+                  Utf8Strn0Cpy(value, base, lengthUtf8);
+                  lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+                  SetBase(base);
+                  pos = Utf8StrLen(base);
+                  if (pos)
+                     pos++;
+                  if (!lengthUtf8) {
+                     Utf8Strn0Cpy(value, " ", length);
+                     lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+                     }
+                  break;
+    case kRight:
+    case kGreen:  // one level down
+                  if (InEditMode())
+                     FindNextLevel();
+                  else
+                     EnterEditMode();
+                  if (!lengthUtf8) {
+                     Utf8Strn0Cpy(value, " ", length);
+                     lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+                     }
+                  pos = Utf8StrLen(base);
+                  if (pos)
+                     pos++;
+                  SetHelpKeys();
+                  break;
+    case kUp|k_Repeat:
+    case kUp:
+    case kYellow|k_Repeat:
+    case kYellow: // previous directory in list
+                  if (!InEditMode())
+                     return cMenuEditItem::ProcessKey(Key);
+                  Find(false);
+                  pos = Utf8StrLen(base);
+                  if (pos)
+                     pos++;
+                  break;
+    case kDown|k_Repeat:
+    case kDown:
+    case kBlue|k_Repeat:
+    case kBlue:   // next directory in list
+                  if (!InEditMode())
+                     return cMenuEditItem::ProcessKey(Key);
+                  Find(true);
+                  pos = Utf8StrLen(base);
+                  if (pos)
+                     pos++;
+                  break;
+    case kOk:     // done
+                  if (!InEditMode())
+                     return cMenuEditItem::ProcessKey(Key);
+                  stripspace(value);
+                  lengthUtf8 = Utf8ToArray(value, valueUtf8, length);
+                  cSkinDisplay::Current()->SetButtons(NULL);
+                  LeaveEditMode(Key == kOk);
+                  break;
+    default:
+                  return cMenuEditItem::ProcessKey(Key);
+    }
+  Set();
+  return osContinue;
+}
+
 // --- cMenuEditStraItem -----------------------------------------------------
 
 cMenuEditStraItem::cMenuEditStraItem(const char *Name, int *Value, int NumStrings, const char * const *Strings)
