@@ -1,7 +1,7 @@
 /*
  * vdr.c: Video Disk Recorder main program
  *
- * Copyright (C) 2000, 2003, 2006 Klaus Schmidinger
+ * Copyright (C) 2000, 2003, 2006, 2008 Klaus Schmidinger
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@
  *
  * The project's page is at http://www.cadsoft.de/vdr
  *
- * $Id: vdr.c 1.305 2008/01/13 11:51:53 kls Exp $
+ * $Id: vdr.c 1.313 2008/03/14 13:22:39 kls Exp $
  */
 
 #include <getopt.h>
@@ -50,6 +50,7 @@
 #include "keys.h"
 #include "libsi/si.h"
 #include "lirc.h"
+#include "livebuffer.h"
 #include "menu.h"
 #include "osdbase.h"
 #include "plugin.h"
@@ -86,7 +87,7 @@
 
 static int LastSignal = 0;
 
-static bool SetUser(const char *UserName)
+static bool SetUser(const char *UserName, bool UserDump)//XXX name?
 {
   if (UserName) {
      struct passwd *user = getpwnam(UserName);
@@ -106,10 +107,8 @@ static bool SetUser(const char *UserName)
         fprintf(stderr, "vdr: cannot set user id %u: %s\n", (unsigned int)user->pw_uid, strerror(errno));
         return false;
         }
-     if (prctl(PR_SET_DUMPABLE, 2, 0, 0, 0) < 0) {
+     if (UserDump && prctl(PR_SET_DUMPABLE, 1, 0, 0, 0) < 0)
         fprintf(stderr, "vdr: warning - cannot set dumpable: %s\n", strerror(errno));
-        // always non-fatal, and will not work with kernel < 2.6.13
-        }
      }
   return true;
 }
@@ -187,6 +186,7 @@ int main(int argc, char *argv[])
 
   bool StartedAsRoot = false;
   const char *VdrUser = NULL;
+  bool UserDump = false;
   int SVDRPport = DEFAULTSVDRPPORT;
   const char *AudioCommand = NULL;
   const char *ConfigDirectory = NULL;
@@ -222,6 +222,7 @@ int main(int argc, char *argv[])
 
   static struct option long_options[] = {
       { "audio",    required_argument, NULL, 'a' },
+      { "buffer",   required_argument, NULL, 'b' },
       { "config",   required_argument, NULL, 'c' },
       { "daemon",   no_argument,       NULL, 'd' },
       { "device",   required_argument, NULL, 'D' },
@@ -241,6 +242,7 @@ int main(int argc, char *argv[])
       { "shutdown", required_argument, NULL, 's' },
       { "terminal", required_argument, NULL, 't' },
       { "user",     required_argument, NULL, 'u' },
+      { "userdump", no_argument,       NULL, 'u' | 0x100 },
       { "version",  no_argument,       NULL, 'V' },
       { "vfat",     no_argument,       NULL, 'v' | 0x100 },
       { "video",    required_argument, NULL, 'v' },
@@ -249,10 +251,14 @@ int main(int argc, char *argv[])
     };
 
   int c;
-  while ((c = getopt_long(argc, argv, "a:c:dD:E:g:hl:L:mp:P:r:s:t:u:v:Vw:", long_options, NULL)) != -1) {
+  while ((c = getopt_long(argc, argv, "a::b:c:dD:E:g:hl:L:mp:P:r:s:t:u:v:Vw:", long_options, NULL)) != -1) {
         switch (c) {
           case 'a': AudioCommand = optarg;
                     break;
+          case 'b': BufferDirectory = optarg;
+                    while (optarg && *optarg && optarg[strlen(optarg) - 1] == '/')
+                          optarg[strlen(optarg) - 1] = 0;
+                    break;
           case 'c': ConfigDirectory = optarg;
                     break;
           case 'd': DaemonMode = true; break;
@@ -346,6 +352,9 @@ int main(int argc, char *argv[])
           case 'u': if (*optarg)
                        VdrUser = optarg;
                     break;
+          case 'u' | 0x100:
+                    UserDump = true;
+                    break;
           case 'V': DisplayVersion = true;
                     break;
           case 'v' | 0x100:
@@ -376,7 +385,7 @@ int main(int argc, char *argv[])
      if (strcmp(VdrUser, "root")) {
         if (!SetKeepCaps(true))
            return 2;
-        if (!SetUser(VdrUser))
+        if (!SetUser(VdrUser, UserDump))
            return 2;
         if (!SetKeepCaps(false))
            return 2;
@@ -394,6 +403,8 @@ int main(int argc, char *argv[])
      if (DisplayHelp) {
         printf("Usage: vdr [OPTIONS]\n\n"          // for easier orientation, this is column 80|
                "  -a CMD,   --audio=CMD    send Dolby Digital audio to stdin of command CMD\n"
+               "  -b DIR,   --buffer=DIR   use DIR as LiveBuffer directory (default is to write\n"
+               "                           it to the video directory)\n"
                "  -c DIR,   --config=DIR   read config files from DIR (default: %s)\n"
                "  -d,       --daemon       run in daemon mode\n"
                "  -D NUM,   --device=NUM   use only the given DVB device (NUM = 0, 1, 2...)\n"
@@ -431,6 +442,7 @@ int main(int argc, char *argv[])
                "  -t TTY,   --terminal=TTY controlling tty\n"
                "  -u USER,  --user=USER    run as user USER; only applicable if started as\n"
                "                           root\n"
+               "            --userdump     allow coredumps if -u is given (debugging)\n"
                "  -v DIR,   --video=DIR    use DIR as video directory (default: %s)\n"
                "  -V,       --version      print version information and exit\n"
                "            --vfat         encode special characters in recording names to\n"
@@ -542,6 +554,7 @@ int main(int argc, char *argv[])
   int MaxLatencyTime = 0;
   bool InhibitEpgScan = false;
   bool IsInfoMenu = false;
+  bool CheckHasProgramme = false;
   cSkin *CurrentSkin = NULL;
 
   // Load plugins:
@@ -549,6 +562,9 @@ int main(int argc, char *argv[])
   if (!PluginManager.LoadPlugins(true))
      EXIT(2);
 
+  if (!BufferDirectory)
+     BufferDirectory = VideoDirectory;
+
   // Configuration data:
 
   if (!ConfigDirectory)
@@ -731,17 +747,16 @@ int main(int argc, char *argv[])
            {
              reelChannelscanIsScanningOnReceivingDevice = false;
            }
-           if (!reelChannelscanIsScanningOnReceivingDevice && Now - lastTime > MINCHANNELWAIT) {
+           if (!reelChannelscanIsScanningOnReceivingDevice && (!Menu || CheckHasProgramme) && Now - lastTime > MINCHANNELWAIT) { // !Menu to avoid interfering with the CAM if a CAM menu is open
               cChannel *Channel = Channels.GetByNumber(cDevice::CurrentChannel());
               if (Channel && (Channel->Vpid() || Channel->Apid(0))) {
                  if (!Channels.SwitchTo(cDevice::CurrentChannel()) // try to switch to the original channel...
-                     && !(LastTimerChannel > 0 && Channels.SwitchTo(LastTimerChannel)) // ...or the one used by the last timer...
-                     && !cDevice::SwitchChannel(1) // ...or the next higher available one...
-                     && !cDevice::SwitchChannel(-1)) // ...or the next lower available one
+                     && !(LastTimerChannel > 0 && Channels.SwitchTo(LastTimerChannel))) // ...or the one used by the last timer...
                     ;
                  }
               lastTime = Now; // don't do this too often
               LastTimerChannel = -1;
+              CheckHasProgramme = false;
               }
            }
         // Restart the Watchdog timer:
@@ -788,8 +803,11 @@ int main(int argc, char *argv[])
            }
         // Channel display:
         if (!EITScanner.Active() && cDevice::CurrentChannel() != LastChannel) {
-           if (!Menu)
+           if (!Menu) {
+              if (cControl::Control(true))
+                 cControl::Control(true)->Hide();
               Menu = new cDisplayChannel(cDevice::CurrentChannel(), LastChannel >= 0);
+	      }
            LastChannel = cDevice::CurrentChannel();
            LastChannelChanged = Now;
            }
@@ -880,8 +898,10 @@ int main(int argc, char *argv[])
                            }
                         if (cDevice::PrimaryDevice()->HasDecoder() && !cDevice::PrimaryDevice()->HasProgramme()) {
                            // the previous SwitchChannel() has switched away the current live channel
-                           Channels.SwitchTo(Timer->Channel()->Number()); // avoids toggling between old channel and black screen
-                           Skins.Message(mtInfo, tr("Upcoming VPS recording!"));
+                           cDevice::SetAvoidDevice(Device);
+                           if (!Channels.SwitchTo(cDevice::CurrentChannel())) // try to switch to the original channel on a different device...
+                              Channels.SwitchTo(Timer->Channel()->Number()); // ...or avoid toggling between old channel and black screen
+                           Skins.Message(mtInfo, tr("Upcoming recording!"));
                            }
                         }
                      }
@@ -902,8 +922,9 @@ int main(int argc, char *argv[])
         if (!Skins.IsOpen())
            Skins.ProcessQueuedMessages();
         // User Input:
-        cOsdObject *Interact = Menu ? Menu : cControl::Control();
+        cOsdObject *Interact = Menu ? Menu : cControl::Control(true);
         eKeys key = Interface->GetKey(!Interact || !Interact->NeedsFastResponse());
+        Interact = Menu ? Menu : cControl::Control();
         if (ISREALKEY(key)) {
            EITScanner.Activity();
            // Cancel shutdown countdown:
@@ -921,9 +942,9 @@ int main(int argc, char *argv[])
                bool WasMenu = Interact && Interact->IsMenu();
                if (Menu)
                   DELETE_MENU;
-               else if (cControl::Control()) {
+               else if (cControl::Control(true)) {
                   if (cOsd::IsOpen())
-                     cControl::Control()->Hide();
+                     cControl::Control(true)->Hide();
                   else
                      WasOpen = false;
                   }
@@ -958,8 +979,8 @@ int main(int argc, char *argv[])
           // Direct main menu functions:
           #define DirectMainFunction(function)\
             DELETE_MENU;\
-            if (cControl::Control())\
-               cControl::Control()->Hide();\
+            if (cControl::Control(true))\
+               cControl::Control(true)->Hide();\
             Menu = new cMenuMain(function);\
             key = kNone; // nobody else needs to see this key
           case kSchedule:   DirectMainFunction(osSchedule); break;
@@ -973,8 +994,8 @@ int main(int argc, char *argv[])
                const char *PluginName = cRemote::GetPlugin();
                if (PluginName) {
                   DELETE_MENU;
-                  if (cControl::Control())
-                     cControl::Control()->Hide();
+                  if (cControl::Control(true))
+                     cControl::Control(true)->Hide();
                   cPlugin *plugin = cPluginManager::GetPlugin(PluginName);
                   if (plugin) {
                      Menu = plugin->MainMenuAction();
@@ -992,8 +1013,11 @@ int main(int argc, char *argv[])
           case kChanUp:
           case kChanDn|k_Repeat:
           case kChanDn:
-               if (!Interact)
+               if (!Interact) {
+                  if (cControl::Control(true))
+                     cControl::Control(true)->Hide();
                   Menu = new cDisplayChannel(NORMALKEY(key));
+		  }
                else if (cDisplayChannel::IsOpen() || cControl::Control()) {
                   Interact->ProcessKey(key);
                   continue;
@@ -1023,8 +1047,8 @@ int main(int argc, char *argv[])
                break;
           // Audio track control:
           case kAudio:
-               if (cControl::Control())
-                  cControl::Control()->Hide();
+               if (cControl::Control(true))
+                  cControl::Control(true)->Hide();
                if (!cDisplayTracks::IsOpen()) {
                   DELETE_MENU;
                   Menu = cDisplayTracks::Create();
@@ -1047,7 +1071,7 @@ int main(int argc, char *argv[])
                break;
           // Pausing live video:
           case kPause:
-               if (!cControl::Control()) {
+               if (!cControl::Control() && !cLiveBufferManager::GetLiveBufferControl()) {
                   DELETE_MENU;
                   if (!cRecordControls::PauseLiveVideo())
                      Skins.Message(mtError, tr("No free DVB device to record!"));
@@ -1056,7 +1080,7 @@ int main(int argc, char *argv[])
                break;
           // Instant recording:
           case kRecord:
-               if (!cControl::Control()) {
+               if (!cControl::Control() && !cLiveBufferManager::GetLiveBufferControl()) {
                   if (cRecordControls::Start())
                      Skins.Message(mtInfo, tr("Recording started"));
                   key = kNone; // nobody else needs to see this key
@@ -1108,12 +1132,25 @@ int main(int argc, char *argv[])
                  state = osEnd;
               }
            switch (state) {
-             case osPause:  DELETE_MENU;
+             case osPause:  if (cLiveBufferManager::GetLiveBufferControl()) {
+                               DELETE_MENU;
+                               if (cControl::Control(true)) {
+                                  cControl::Control(true)->ProcessKey(kPlay);
+                                  cControl::Control(true)->ProcessKey(kPause);
+                                  }
+                               break;
+                               }
+                            DELETE_MENU;
                             cControl::Shutdown(); // just in case
                             if (!cRecordControls::PauseLiveVideo())
                                Skins.Message(mtError, tr("No free DVB device to record!"));
                             break;
-             case osRecord: DELETE_MENU;
+             case osRecord: if (cLiveBufferManager::GetLiveBufferControl()) {
+                               if (cControl::Control(true))
+                                  cControl::Control(true)->ProcessKey(kRecord);
+                               break;
+                               }
+                            DELETE_MENU;
                             if (cRecordControls::Start())
                                Skins.Message(mtInfo, tr("Recording started"));
                             break;
@@ -1121,6 +1158,7 @@ int main(int argc, char *argv[])
                             DELETE_MENU;
                             cControl::Shutdown();
                             Menu = new cMenuMain(osRecordings);
+                            CheckHasProgramme = true; // to have live tv after stopping replay with 'Back'
                             break;
              case osReplay: DELETE_MENU;
                             cControl::Shutdown();
@@ -1151,6 +1189,10 @@ int main(int argc, char *argv[])
              }
            }
         else {
+           eOSState state = osUnknown;
+           if (cLiveBufferManager::GetLiveBufferControl())
+              state = cLiveBufferManager::GetLiveBufferControl()->ProcessKey(key);
+           if (state == osUnknown) {
            // Key functions in "normal" viewing mode:
            if (key != kNone && KeyMacros.Get(key)) {
               cRemote::PutMacro(key);
@@ -1182,6 +1224,8 @@ int main(int argc, char *argv[])
              case kUp:
              case kDown|k_Repeat:
              case kDown:
+                  if (cControl::Control(true))
+                     cControl::Control(true)->Hide();
                   Menu = new cDisplayChannel(NORMALKEY(key));
                   break;
              // Viewing Control:
@@ -1196,6 +1240,7 @@ int main(int argc, char *argv[])
              default:    break;
              }
            }
+	   }
         if (!Menu) {
            if (!InhibitEpgScan)
               EITScanner.Process();
@@ -1265,6 +1310,8 @@ Exit:
   signal(SIGPIPE, SIG_DFL);
   signal(SIGALRM, SIG_DFL);
 
+  cLiveBufferManager::Shutdown();
+
   PluginManager.StopPlugins();
   cRecordControls::Shutdown();
   cCutter::Stop();
